==> simplify-docx-0.1.1.tar.gz: simplify-docx-0.1.1/setup.py <==
#!/usr/bin/env python
# -*- encoding: utf-8 -*-
from __future__ import absolute_import
from __future__ import print_function

import io
import re
from glob import glob
from os.path import basename
from os.path import dirname
from os.path import join
from os.path import splitext

from setuptools import find_packages
from setuptools import setup


def read(*names, **kwargs):
    return io.open(
        join(dirname(__file__), *names), encoding=kwargs.get("encoding", "utf8")
    ).read()


setup(
    name="simplify-docx",
    version="0.1.1",
    description="A utility for simplifying python-docx document objects",
    long_description="%s\n%s"
    % (
        re.compile("^.. start-badges.*^.. end-badges", re.M | re.S).sub(
            "", read("README.md")
        ),
        re.sub(":[a-z]+:`~?(.*?)`", r"``\1``", read("CHANGELOG.md")),
    ),
    author="Microsoft Research",
    author_email="jathorpe@microsoft.com",
    url="https://microsofteconomics.visualstudio.com/EconTools/_git/loadify?_a=history",
    packages=find_packages("src"),
    package_dir={"": "src"},
    py_modules=[splitext(basename(path))[0] for path in glob("src/*.py")],
    include_package_data=True,
    zip_safe=False,
    long_description_content_type="text/markdown",
    classifiers=[
        # complete classifier list: http://pypi.python.org/pypi?%3Aaction=list_classifiers
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Operating System :: Unix",
        "Operating System :: POSIX",
        "Operating System :: Microsoft :: Windows",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Utilities",
    ],
    keywords=["sql", "csv"],
    install_requires=[
        "lxml>=4.3.3,<5",
        "more-itertools==7.0.0",
        "python-docx==0.8.10",
        "six>=1.12.0<2",
        "wincertstore==0.2",
    ],
    extras_require={':python_version=="2.6"': ["argparse"]},
    entry_points={"console_scripts": ["loadify = loadify:loadify"]},
)

==> simplify-docx-0.1.2.tar.gz: simplify-docx-0.1.2/setup.py <==
#!/usr/bin/env python
# -*- encoding: utf-8 -*-
from __future__ import absolute_import
from __future__ import print_function

import io
import re
from glob import glob
from os.path import basename
from os.path import dirname
from os.path import join
from os.path import splitext

from setuptools import find_packages
from setuptools import setup


def read(*names, **kwargs):
    return io.open(
        join(dirname(__file__), *names), encoding=kwargs.get("encoding", "utf8")
    ).read()


setup(
    name="simplify-docx",
    version="0.1.2",
    description="A utility for simplifying python-docx document objects",
    long_description="%s\n"
    % (
        re.compile("^.. start-badges.*^.. end-badges", re.M | re.S).sub(
            "", read("README.md")
        )
    ),
    author="Microsoft Research",
    author_email="jathorpe@microsoft.com",
    url="https://microsofteconomics.visualstudio.com/EconTools/_git/loadify?_a=history",
    packages=find_packages("src"),
    package_dir={"": "src"},
    py_modules=[splitext(basename(path))[0] for path in glob("src/*.py")],
    include_package_data=True,
    zip_safe=False,
    long_description_content_type="text/markdown",
    classifiers=[
        # complete classifier list: http://pypi.python.org/pypi?%3Aaction=list_classifiers
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Operating System :: Unix",
        "Operating System :: POSIX",
        "Operating System :: Microsoft :: Windows",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Utilities",
    ],
    keywords=["sql", "csv"],
    install_requires=[
        "lxml>=4.3.3,<5",
        "more-itertools==7.0.0",
        "python-docx>=0.8.10",
        "six>=1.12.0<2",
        "wincertstore==0.2",
    ],
    extras_require={':python_version=="2.6"': ["argparse"]},
    entry_points={"console_scripts": ["loadify = loadify:loadify"]},
)
